import requests
import time

def download_speed_test(url):
    start_time = time.time()
    response = requests.get(url, stream=True)
    total_length = response.headers.get('content-length')

    if total_length is None:
        print("Error: Could not retrieve the file")
        return

    total_length = int(total_length)
    downloaded = 0

    for data in response.iter_content(chunk_size=4096):
        downloaded += len(data)

    end_time = time.time()
    duration = end_time - start_time
    speed = total_length / duration / 1024 / 1024  # MB/s

    print(f"Download speed: {speed:.2f} MB/s")

def upload_speed_test(url, file_path):
    with open(file_path, 'rb') as f:
        files = {'file': f}
        start_time = time.time()
        response = requests.post(url, files=files)
        end_time = time.time()
        duration = end_time - start_time

        if response.status_code == 200:
            speed = os.path.getsize(file_path) / duration / 1024 / 1024  # MB/s
            print(f"Upload speed: {speed:.2f} MB/s")
        else:
            print("Error: Could not upload the file")

if __name__ == "__main__":
    server_url = 'http://your_server_ip:5000'
    download_url = f"{server_url}/download"
    upload_url = f"{server_url}/upload"

    # 测试下载速度
    download_speed_test(download_url)

    # 生成一个10MB的随机文件用于上传测试
    file_path = 'upload_test_file.bin'
    with open(file_path, 'wb') as f:
        f.write(os.urandom(10 * 1024 * 1024))

    # 测试上传速度
    upload_speed_test(upload_url, file_path)
